import board
import busio
import time
import usb_hid
from adafruit_hid.mouse import Mouse
import adafruit_vcnl4040

# Initialize I2C bus using STEMMA QT port
i2c = busio.I2C(board.SCL1, board.SDA1)

# Initialize VCNL4040 sensor
vcnl4040 = adafruit_vcnl4040.VCNL4040(i2c)

# Initialize mouse HID
mouse = Mouse(usb_hid.devices)

# Set the proximity threshold for significant movement
PROXIMITY_THRESHOLD = 10

# Store the previous proximity reading
last_proximity = vcnl4040.proximity

while True:
    try:
        # Read the current proximity value
        current_proximity = vcnl4040.proximity
        print(f"Current proximity: {current_proximity}")

        # Check if proximity has increased by more than the threshold (movement closer)
        if (current_proximity - last_proximity) > PROXIMITY_THRESHOLD:
            # Simulate a left mouse click (press and release)
            mouse.click(Mouse.LEFT_BUTTON)
            print("Left mouse click!")

        # Update last_proximity for the next check
        last_proximity = current_proximity

        # Wait for 1 second before checking again
        time.sleep(1)

    except OSError as e:
        print("Sensor error:", e)
